@@ -1,47 +1,50 @@
-from statsmodels.compat.python import lzip, string_types
+from statsmodels.compat.python import lzip
+
 import numpy as np
 from scipy import stats
+
 from statsmodels.regression.linear_model import OLS
 from statsmodels.tools.tools import add_constant
-from statsmodels.tools.decorators import (resettable_cache,
-                                          cache_readonly,
-                                          cache_writable)
-
+from statsmodels.tools.decorators import cache_readonly
+from statsmodels.distributions import ECDF
 from . import utils
 
 __all__ = ['qqplot', 'qqplot_2samples', 'qqline', 'ProbPlot']
 
+
 class ProbPlot(object):
     """
-    Class for convenient construction of Q-Q, P-P, and probability plots.
+    Q-Q and P-P Probability Plots
 
     Can take arguments specifying the parameters for dist or fit them
     automatically. (See fit under kwargs.)
 
     Parameters
     ----------
-    data : array-like
-        1d data array
-    dist : A scipy.stats or statsmodels distribution
-        Compare x against dist. The default is
-        scipy.stats.distributions.norm (a standard normal).
-    distargs : tuple
-        A tuple of arguments passed to dist to specify it fully
-        so dist.ppf may be called.
-    loc : float
-        Location parameter for dist
-    a : float
-        Offset for the plotting position of an expected order
-        statistic, for example. The plotting positions are given
-        by (i - a)/(nobs - 2*a + 1) for i in range(0,nobs+1)
-    scale : float
-        Scale parameter for dist
-    fit : boolean
+    data : array_like
+        A 1d data array
+    dist : callable
+        Compare x against dist. A scipy.stats or statsmodels distribution. The
+        default is scipy.stats.distributions.norm (a standard normal).
+    fit : bool
         If fit is false, loc, scale, and distargs are passed to the
         distribution. If fit is True then the parameters for dist
         are fit automatically using dist.fit. The quantiles are formed
         from the standardized data, after subtracting the fitted loc
         and dividing by the fitted scale.
+    distargs : tuple
+        A tuple of arguments passed to dist to specify it fully
+        so dist.ppf may be called. distargs must not contain loc
+        or scale. These values must be passed using the loc or
+        scale inputs.
+    a : float
+        Offset for the plotting position of an expected order
+        statistic, for example. The plotting positions are given
+        by (i - a)/(nobs - 2*a + 1) for i in range(0,nobs+1)
+    loc : float
+        Location parameter for dist
+    scale : float
+        Scale parameter for dist
 
     See Also
     --------
@@ -67,17 +70,19 @@ class ProbPlot(object):
 
     Examples
     --------
-    >>> import statsmodels.api as sm
-    >>> from matplotlib import pyplot as plt
+    The first example shows a Q-Q plot for regression residuals
 
     >>> # example 1
-    >>> data = sm.datasets.longley.load()
+    >>> import statsmodels.api as sm
+    >>> from matplotlib import pyplot as plt
+    >>> data = sm.datasets.longley.load(as_pandas=False)
     >>> data.exog = sm.add_constant(data.exog)
     >>> model = sm.OLS(data.endog, data.exog)
     >>> mod_fit = model.fit()
     >>> res = mod_fit.resid # residuals
     >>> probplot = sm.ProbPlot(res)
-    >>> probplot.qqplot()
+    >>> fig = probplot.qqplot()
+    >>> h = plt.title('Ex. 1 - qqplot - residuals of OLS fit')
     >>> plt.show()
 
     qqplot of the residuals against quantiles of t-distribution with 4
@@ -87,6 +92,7 @@ class ProbPlot(object):
     >>> import scipy.stats as stats
     >>> probplot = sm.ProbPlot(res, stats.t, distargs=(4,))
     >>> fig = probplot.qqplot()
+    >>> h = plt.title('Ex. 2 - qqplot - residuals against quantiles of t-dist')
     >>> plt.show()
 
     qqplot against same as above, but with mean 3 and std 10:
@@ -94,6 +100,7 @@ class ProbPlot(object):
     >>> # example 3
     >>> probplot = sm.ProbPlot(res, stats.t, distargs=(4,), loc=3, scale=10)
     >>> fig = probplot.qqplot()
+    >>> h = plt.title('Ex. 3 - qqplot - resids vs quantiles of t-dist')
     >>> plt.show()
 
     Automatically determine parameters for t distribution including the
@@ -102,9 +109,10 @@ class ProbPlot(object):
     >>> # example 4
     >>> probplot = sm.ProbPlot(res, stats.t, fit=True)
     >>> fig = probplot.qqplot(line='45')
+    >>> h = plt.title('Ex. 4 - qqplot - resids vs. quantiles of fitted t-dist')
     >>> plt.show()
 
-    A second `ProbPlot` object can be used to compare two seperate sample
+    A second `ProbPlot` object can be used to compare two separate sample
     sets by using the `other` kwarg in the `qqplot` and `ppplot` methods.
 
     >>> # example 5
@@ -114,6 +122,37 @@ class ProbPlot(object):
     >>> pp_x = sm.ProbPlot(x, fit=True)
     >>> pp_y = sm.ProbPlot(y, fit=True)
     >>> fig = pp_x.qqplot(line='45', other=pp_y)
+    >>> h = plt.title('Ex. 5 - qqplot - compare two sample sets')
+    >>> plt.show()
+
+    In qqplot, sample size of `other` can be equal or larger than the first.
+    In case of larger, size of `other` samples will be reduced to match the
+    size of the first by interpolation
+
+    >>> # example 6
+    >>> x = np.random.normal(loc=8.25, scale=2.75, size=37)
+    >>> y = np.random.normal(loc=8.75, scale=3.25, size=57)
+    >>> pp_x = sm.ProbPlot(x, fit=True)
+    >>> pp_y = sm.ProbPlot(y, fit=True)
+    >>> fig = pp_x.qqplot(line='45', other=pp_y)
+    >>> title = 'Ex. 6 - qqplot - compare different sample sizes'
+    >>> h = plt.title(title)
+    >>> plt.show()
+
+    In ppplot, sample size of `other` and the first can be different. `other`
+    will be used to estimate an empirical cumulative distribution function
+    (ECDF). ECDF(x) will be plotted against p(x)=0.5/n, 1.5/n, ..., (n-0.5)/n
+    where x are sorted samples from the first.
+
+    >>> # example 7
+    >>> x = np.random.normal(loc=8.25, scale=2.75, size=37)
+    >>> y = np.random.normal(loc=8.75, scale=3.25, size=57)
+    >>> pp_x = sm.ProbPlot(x, fit=True)
+    >>> pp_y = sm.ProbPlot(y, fit=True)
+    >>> fig = pp_y.ppplot(line='45', other=pp_x)
+    >>> h = plt.title('Ex. 7A- ppplot - compare two sample sets, other=pp_x')
+    >>> fig = pp_x.ppplot(line='45', other=pp_y)
+    >>> h = plt.title('Ex. 7B- ppplot - compare two sample sets, other=pp_y')
     >>> plt.show()
 
     The following plot displays some options, follow the link to see the
@@ -122,8 +161,8 @@ class ProbPlot(object):
     .. plot:: plots/graphics_gofplots_qqplot.py
     """
 
-    def __init__(self, data, dist=stats.norm, fit=False,
-                 distargs=(), a=0, loc=0, scale=1):
+    def __init__(self, data, dist=stats.norm, fit=False, distargs=(), a=0,
+                 loc=0, scale=1):
 
         self.data = data
         self.a = a
@@ -131,36 +170,49 @@ class ProbPlot(object):
         self.distargs = distargs
         self.fit = fit
 
-        if isinstance(dist, string_types):
+        if isinstance(dist, str):
             dist = getattr(stats, dist)
 
-        self.fit_params = dist.fit(data)
         if fit:
+            self.fit_params = dist.fit(data)
             self.loc = self.fit_params[-2]
             self.scale = self.fit_params[-1]
             if len(self.fit_params) > 2:
                 self.dist = dist(*self.fit_params[:-2],
-                                 **dict(loc = 0, scale = 1))
+                                 **dict(loc=0, scale=1))
             else:
                 self.dist = dist(loc=0, scale=1)
-        elif distargs or loc == 0 or scale == 1:
-            self.dist = dist(*distargs, **dict(loc=loc, scale=scale))
+        elif distargs or loc != 0 or scale != 1:
+            try:
+                self.dist = dist(*distargs, **dict(loc=loc, scale=scale))
+            except Exception:
+                distargs = ', '.join([str(da) for da in distargs])
+                cmd = 'dist({distargs}, loc={loc}, scale={scale})'
+                cmd = cmd.format(distargs=distargs, loc=loc, scale=scale)
+                raise TypeError('Initializing the distribution failed.  This '
+                                'can occur if distargs contains loc or scale. '
+                                'The distribution initialization command '
+                                'is:\n{cmd}'.format(cmd=cmd))
             self.loc = loc
             self.scale = scale
+            self.fit_params = np.r_[distargs, loc, scale]
         else:
             self.dist = dist
             self.loc = loc
             self.scale = scale
+            self.fit_params = np.r_[loc, scale]
 
         # propertes
-        self._cache = resettable_cache()
+        self._cache = {}
 
     @cache_readonly
     def theoretical_percentiles(self):
+        """Theoretical percentiles"""
         return plotting_pos(self.nobs, self.a)
 
     @cache_readonly
     def theoretical_quantiles(self):
+        """Theoretical quantiles"""
         try:
             return self.dist.ppf(self.theoretical_percentiles)
         except TypeError:
@@ -173,12 +225,14 @@ class ProbPlot(object):
 
     @cache_readonly
     def sorted_data(self):
+        """sorted data"""
         sorted_data = np.array(self.data, copy=True)
         sorted_data.sort()
         return sorted_data
 
     @cache_readonly
     def sample_quantiles(self):
+        """sample quantiles"""
         if self.fit and self.loc != 0 and self.scale != 1:
             return (self.sorted_data-self.loc)/self.scale
         else:
@@ -186,6 +240,7 @@ class ProbPlot(object):
 
     @cache_readonly
     def sample_percentiles(self):
+        """Sample percentiles"""
         quantiles = \
             (self.sorted_data - self.fit_params[-2])/self.fit_params[-1]
         return self.dist.cdf(quantiles)
@@ -193,40 +248,45 @@ class ProbPlot(object):
     def ppplot(self, xlabel=None, ylabel=None, line=None, other=None,
                ax=None, **plotkwargs):
         """
-        P-P plot of the percentiles (probabilities) of x versus the
-        probabilities (percetiles) of a distribution.
+        Plot of the percentiles of x versus the percentiles of a distribution.
 
         Parameters
         ----------
-        xlabel, ylabel : str or None, optional
-            User-provided lables for the x-axis and y-axis. If None (default),
+        xlabel : str or None, optional
+            User-provided labels for the x-axis. If None (default),
             other values are used depending on the status of the kwarg `other`.
-        line : str {'45', 's', 'r', q'} or None, optional
+        ylabel : str or None, optional
+            User-provided labels for the y-axis. If None (default),
+            other values are used depending on the status of the kwarg `other`.
+        line : {None, '45', 's', 'r', q'}, optional
             Options for the reference line to which the data is compared:
 
-            - '45' - 45-degree line
-            - 's' - standardized line, the expected order statistics are scaled
-              by the standard deviation of the given sample and have the mean
-              added to them
-            - 'r' - A regression line is fit
-            - 'q' - A line is fit through the quartiles.
-            - None - by default no reference line is added to the plot.
+                - '45': 45-degree line
+                - 's': standardized line, the expected order statistics are
+                  scaled by the standard deviation of the given sample and have
+                  the mean added to them
+                - 'r': A regression line is fit
+                - 'q': A line is fit through the quartiles.
+                - None: by default no reference line is added to the plot.
 
-        other : `ProbPlot` instance, array-like, or None, optional
-            If provided, the sample quantiles of this `ProbPlot` instance are
-            plotted against the sample quantiles of the `other` `ProbPlot`
-            instance. If an array-like object is provided, it will be turned
-            into a `ProbPlot` instance using default parameters. If not provided
-            (default), the theoretical quantiles are used.
-        ax : Matplotlib AxesSubplot instance, optional
+        other : ProbPlot, array_like, or None, optional
+            If provided, ECDF(x) will be plotted against p(x) where x are
+            sorted samples from `self`. ECDF is an empirical cumulative
+            distribution function estimated from `other` and
+            p(x) = 0.5/n, 1.5/n, ..., (n-0.5)/n where n is the number of
+            samples in `self`. If an array-object is provided, it will be
+            turned into a `ProbPlot` instance default parameters. If not
+            provided (default), `self.dist(x)` is be plotted against p(x).
+
+        ax : AxesSubplot, optional
             If given, this subplot is used to plot in instead of a new figure
             being created.
-        **plotkwargs : additional matplotlib arguments to be passed to the
-            `plot` command.
+        **plotkwargs
+            Additional arguments to be passed to the `plot` command.
 
         Returns
         -------
-        fig : Matplotlib figure instance
+        Figure
             If `ax` is None, the created figure.  Otherwise the figure to which
             `ax` is connected.
         """
@@ -235,9 +295,10 @@ class ProbPlot(object):
             if not check_other:
                 other = ProbPlot(other)
 
-            fig, ax = _do_plot(other.sample_percentiles,
-                               self.sample_percentiles,
-                               self.dist, ax=ax, line=line,
+            p_x = self.theoretical_percentiles
+            ecdf_x = ECDF(other.sample_quantiles)(self.sample_quantiles)
+
+            fig, ax = _do_plot(p_x, ecdf_x, self.dist, ax=ax, line=line,
                                **plotkwargs)
 
             if xlabel is None:
@@ -266,15 +327,20 @@ class ProbPlot(object):
     def qqplot(self, xlabel=None, ylabel=None, line=None, other=None,
                ax=None, **plotkwargs):
         """
-        Q-Q plot of the quantiles of x versus the quantiles/ppf of a
-        distribution or the quantiles of another `ProbPlot` instance.
+        Plot of the quantiles of x versus the quantiles/ppf of a distribution.
+
+        Can also be used to plot against the quantiles of another `ProbPlot`
+        instance.
 
         Parameters
         ----------
-        xlabel, ylabel : str or None, optional
-            User-provided lables for the x-axis and y-axis. If None (default),
+        xlabel : {None, str}
+            User-provided labels for the x-axis. If None (default),
             other values are used depending on the status of the kwarg `other`.
-        line : str {'45', 's', 'r', q'} or None, optional
+        ylabel : {None, str}
+            User-provided labels for the y-axis. If None (default),
+            other values are used depending on the status of the kwarg `other`.
+        line : {None, '45', 's', 'r', q'}, optional
             Options for the reference line to which the data is compared:
 
             - '45' - 45-degree line
@@ -285,21 +351,25 @@ class ProbPlot(object):
             - 'q' - A line is fit through the quartiles.
             - None - by default no reference line is added to the plot.
 
-        other : `ProbPlot` instance, array-like, or None, optional
+        other : {ProbPlot, array_like, None}, optional
             If provided, the sample quantiles of this `ProbPlot` instance are
             plotted against the sample quantiles of the `other` `ProbPlot`
-            instance. If an array-like object is provided, it will be turned
-            into a `ProbPlot` instance using default parameters. If not
-            provided (default), the theoretical quantiles are used.
-        ax : Matplotlib AxesSubplot instance, optional
+            instance. Sample size of `other` must be equal or larger than
+            this `ProbPlot` instance. If the sample size is larger, sample
+            quantiles of `other` will be interpolated to match the sample size
+            of this `ProbPlot` instance. If an array-like object is provided,
+            it will be turned into a `ProbPlot` instance using default
+            parameters. If not provided (default), the theoretical quantiles
+            are used.
+        ax : AxesSubplot, optional
             If given, this subplot is used to plot in instead of a new figure
             being created.
-        **plotkwargs : additional matplotlib arguments to be passed to the
-            `plot` command.
+        **plotkwargs
+            Additional arguments to be passed to the `plot` command.
 
         Returns
         -------
-        fig : Matplotlib figure instance
+        Figure
             If `ax` is None, the created figure.  Otherwise the figure to which
             `ax` is connected.
         """
@@ -308,9 +378,19 @@ class ProbPlot(object):
             if not check_other:
                 other = ProbPlot(other)
 
-            fig, ax = _do_plot(other.sample_quantiles,
-                               self.sample_quantiles,
-                               self.dist, ax=ax, line=line,
+            s_self = self.sample_quantiles
+            s_other = other.sample_quantiles
+
+            if len(s_self) > len(s_other):
+                raise ValueError("Sample size of `other` must be equal or " +
+                                 "larger than this `ProbPlot` instance")
+            elif len(s_self) < len(s_other):
+                # Use quantiles of the smaller set and interpolate quantiles of
+                # the larger data set
+                p = plotting_pos(self.nobs, self.a)
+                s_other = stats.mstats.mquantiles(s_other, p)
+
+            fig, ax = _do_plot(s_other, s_self, self.dist, ax=ax, line=line,
                                **plotkwargs)
 
             if xlabel is None:
@@ -336,18 +416,20 @@ class ProbPlot(object):
     def probplot(self, xlabel=None, ylabel=None, line=None,
                  exceed=False, ax=None, **plotkwargs):
         """
-        Probability plot of the unscaled quantiles of x versus the
-        probabilities of a distibution (not to be confused with a P-P plot).
+        Plot of unscaled quantiles of x against the prob of a distribution.
 
         The x-axis is scaled linearly with the quantiles, but the probabilities
         are used to label the axis.
 
         Parameters
         ----------
-        xlabel, ylabel : str or None, optional
-            User-provided lables for the x-axis and y-axis. If None (default),
+        xlabel : {None, str}, optional
+            User-provided labels for the x-axis. If None (default),
             other values are used depending on the status of the kwarg `other`.
-        line : str {'45', 's', 'r', q'} or None, optional
+        ylabel : {None, str}, optional
+            User-provided labels for the y-axis. If None (default),
+            other values are used depending on the status of the kwarg `other`.
+        line : {None, '45', 's', 'r', q'}, optional
             Options for the reference line to which the data is compared:
 
             - '45' - 45-degree line
@@ -358,23 +440,21 @@ class ProbPlot(object):
             - 'q' - A line is fit through the quartiles.
             - None - by default no reference line is added to the plot.
 
-        exceed : boolean, optional
-
-             - If False (default) the raw sample quantiles are plotted against
-               the theoretical quantiles, show the probability that a sample
-               will not exceed a given value
-             - If True, the theoretical quantiles are flipped such that the
-               figure displays the probability that a sample will exceed a
-               given value.
-        ax : Matplotlib AxesSubplot instance, optional
+        exceed : bool, optional
+            If False (default) the raw sample quantiles are plotted against
+            the theoretical quantiles, show the probability that a sample will
+            not exceed a given value. If True, the theoretical quantiles are
+            flipped such that the figure displays the probability that a
+            sample will exceed a given value.
+        ax : AxesSubplot, optional
             If given, this subplot is used to plot in instead of a new figure
             being created.
-        **plotkwargs : additional matplotlib arguments to be passed to the
-            `plot` command.
+        **plotkwargs
+            Additional arguments to be passed to the `plot` command.
 
         Returns
         -------
-        fig : Matplotlib figure instance
+        Figure
             If `ax` is None, the created figure.  Otherwise the figure to which
             `ax` is connected.
         """
@@ -403,8 +483,9 @@ class ProbPlot(object):
 
         return fig
 
+
 def qqplot(data, dist=stats.norm, distargs=(), a=0, loc=0, scale=1, fit=False,
-           line=None, ax=None):
+           line=None, ax=None, **plotkwargs):
     """
     Q-Q plot of the quantiles of x versus the quantiles/ppf of a distribution.
 
@@ -413,29 +494,29 @@ def qqplot(data, dist=stats.norm, distargs=(), a=0, loc=0, scale=1, fit=False,
 
     Parameters
     ----------
-    data : array-like
-        1d data array
-    dist : A scipy.stats or statsmodels distribution
-        Compare x against dist. The default
-        is scipy.stats.distributions.norm (a standard normal).
+    data : array_like
+        A 1d data array.
+    dist : callable
+        Comparison distribution. The default is
+        scipy.stats.distributions.norm (a standard normal).
     distargs : tuple
         A tuple of arguments passed to dist to specify it fully
         so dist.ppf may be called.
-    loc : float
-        Location parameter for dist
     a : float
         Offset for the plotting position of an expected order statistic, for
         example. The plotting positions are given by (i - a)/(nobs - 2*a + 1)
         for i in range(0,nobs+1)
+    loc : float
+        Location parameter for dist
     scale : float
         Scale parameter for dist
-    fit : boolean
+    fit : bool
         If fit is false, loc, scale, and distargs are passed to the
         distribution. If fit is True then the parameters for dist
         are fit automatically using dist.fit. The quantiles are formed
         from the standardized data, after subtracting the fitted loc
         and dividing by the fitted scale.
-    line : str {'45', 's', 'r', q'} or None
+    line : {None, '45', 's', 'r', q'}
         Options for the reference line to which the data is compared:
 
         - '45' - 45-degree line
@@ -446,13 +527,15 @@ def qqplot(data, dist=stats.norm, distargs=(), a=0, loc=0, scale=1, fit=False,
         - 'q' - A line is fit through the quartiles.
         - None - by default no reference line is added to the plot.
 
-    ax : Matplotlib AxesSubplot instance, optional
+    ax : AxesSubplot, optional
         If given, this subplot is used to plot in instead of a new figure being
         created.
+    **plotkwargs
+        Additional matplotlib arguments to be passed to the `plot` command.
 
     Returns
     -------
-    fig : Matplotlib figure instance
+    Figure
         If `ax` is None, the created figure.  Otherwise the figure to which
         `ax` is connected.
 
@@ -460,11 +543,16 @@ def qqplot(data, dist=stats.norm, distargs=(), a=0, loc=0, scale=1, fit=False,
     --------
     scipy.stats.probplot
 
+    Notes
+    -----
+    Depends on matplotlib. If `fit` is True then the parameters are fit using
+    the distribution's fit() method.
+
     Examples
     --------
     >>> import statsmodels.api as sm
     >>> from matplotlib import pyplot as plt
-    >>> data = sm.datasets.longley.load()
+    >>> data = sm.datasets.longley.load(as_pandas=False)
     >>> data.exog = sm.add_constant(data.exog)
     >>> mod_fit = sm.OLS(data.endog, data.exog).fit()
     >>> res = mod_fit.resid # residuals
@@ -492,19 +580,15 @@ def qqplot(data, dist=stats.norm, distargs=(), a=0, loc=0, scale=1, fit=False,
     The following plot displays some options, follow the link to see the code.
 
     .. plot:: plots/graphics_gofplots_qqplot.py
-
-    Notes
-    -----
-    Depends on matplotlib. If `fit` is True then the parameters are fit using
-    the distribution's fit() method.
-
     """
     probplot = ProbPlot(data, dist=dist, distargs=distargs,
                          fit=fit, a=a, loc=loc, scale=scale)
-    fig = probplot.qqplot(ax=ax, line=line)
+    fig = probplot.qqplot(ax=ax, line=line, **plotkwargs)
     return fig
 
-def qqplot_2samples(data1, data2, xlabel=None, ylabel=None, line=None, ax=None):
+
+def qqplot_2samples(data1, data2, xlabel=None, ylabel=None, line=None,
+                    ax=None):
     """
     Q-Q Plot of two samples' quantiles.
 
@@ -515,11 +599,17 @@ def qqplot_2samples(data1, data2, xlabel=None, ylabel=None, line=None, ax=None):
 
     Parameters
     ----------
-    data1, data2 : array-like (1d) or `ProbPlot` instances
-    xlabel, ylabel : str or None
-        User-provided labels for the x-axis and y-axis. If None (default),
+    data1 : {array_like, ProbPlot}
+        Data to plot along x axis.
+    data2 : {array_like, ProbPlot}
+        Data to plot along y axis.
+    xlabel : {None, str}
+        User-provided labels for the x-axis. If None (default),
         other values are used.
-    line : str {'45', 's', 'r', q'} or None
+    ylabel : {None, str}
+        User-provided labels for the y-axis. If None (default),
+        other values are used.
+    line : {None, '45', 's', 'r', q'}
         Options for the reference line to which the data is compared:
 
         - '45' - 45-degree line
@@ -530,13 +620,13 @@ def qqplot_2samples(data1, data2, xlabel=None, ylabel=None, line=None, ax=None):
         - 'q' - A line is fit through the quartiles.
         - None - by default no reference line is added to the plot.
 
-    ax : Matplotlib AxesSubplot instance, optional
+    ax : AxesSubplot, optional
         If given, this subplot is used to plot in instead of a new figure being
         created.
 
     Returns
     -------
-    fig : Matplotlib figure instance
+    Figure
         If `ax` is None, the created figure.  Otherwise the figure to which
         `ax` is connected.
 
@@ -544,14 +634,6 @@ def qqplot_2samples(data1, data2, xlabel=None, ylabel=None, line=None, ax=None):
     --------
     scipy.stats.probplot
 
-    Examples
-    --------
-    >>> x = np.random.normal(loc=8.5, scale=2.5, size=37)
-    >>> y = np.random.normal(loc=8.0, scale=3.0, size=37)
-    >>> pp_x = sm.ProbPlot(x)
-    >>> pp_y = sm.ProbPlot(y)
-    >>> qqplot_2samples(data1, data2, xlabel=None, ylabel=None, line=None, ax=None):
-
     Notes
     -----
     1) Depends on matplotlib.
@@ -560,12 +642,28 @@ def qqplot_2samples(data1, data2, xlabel=None, ylabel=None, line=None, ax=None):
        `ProbPlot` instance if fine-grained control is needed in the computation
        of the quantiles.
 
-    """
-    check_data1 = isinstance(data1, ProbPlot)
-    check_data2 = isinstance(data2, ProbPlot)
+    Examples
+    --------
+    >>> import statsmodels.api as sm
+    >>> import numpy as np
+    >>> import matplotlib.pyplot as plt
+    >>> from statsmodels.graphics.gofplots import qqplot_2samples
+    >>> x = np.random.normal(loc=8.5, scale=2.5, size=37)
+    >>> y = np.random.normal(loc=8.0, scale=3.0, size=37)
+    >>> pp_x = sm.ProbPlot(x)
+    >>> pp_y = sm.ProbPlot(y)
+    >>> qqplot_2samples(pp_x, pp_y)
+    >>> plt.show()
 
-    if not check_data1 and not check_data2:
+    .. plot:: plots/graphics_gofplots_qqplot_2samples.py
+
+    >>> fig = qqplot_2samples(pp_x, pp_y, xlabel=None, ylabel=None, \
+    ...                       line=None, ax=None)
+    """
+    if not isinstance(data1, ProbPlot):
         data1 = ProbPlot(data1)
+
+    if not isinstance(data2, ProbPlot):
         data2 = ProbPlot(data2)
 
     fig = data1.qqplot(xlabel=xlabel, ylabel=ylabel,
@@ -573,6 +671,7 @@ def qqplot_2samples(data1, data2, xlabel=None, ylabel=None, line=None, ax=None):
 
     return fig
 
+
 def qqline(ax, line, x=None, y=None, dist=None, fmt='r-'):
     """
     Plot a reference line for a qqplot.
@@ -592,16 +691,41 @@ def qqline(ax, line, x=None, y=None, dist=None, fmt='r-'):
         - 'q'  - A line is fit through the quartiles.
         - None - By default no reference line is added to the plot.
 
-    x : array
+    x : ndarray
         X data for plot. Not needed if line is '45'.
-    y : array
+    y : ndarray
         Y data for plot. Not needed if line is '45'.
     dist : scipy.stats.distribution
         A scipy.stats distribution, needed if line is 'q'.
+    fmt : str, optional
+        Line format string passed to `plot`.
 
     Notes
     -----
     There is no return value. The line is plotted on the given `ax`.
+
+    Examples
+    --------
+    Import the food expenditure dataset.  Plot annual food expenditure on x-axis
+    and household income on y-axis.  Use qqline to add regression line into the
+    plot.
+
+    >>> import statsmodels.api as sm
+    >>> import numpy as np
+    >>> import matplotlib.pyplot as plt
+    >>> from statsmodels.graphics.gofplots import qqline
+
+    >>> foodexp = sm.datasets.engel.load(as_pandas=False)
+    >>> x = foodexp.exog
+    >>> y = foodexp.endog
+    >>> ax = plt.subplot(111)
+    >>> plt.scatter(x, y)
+    >>> ax.set_xlabel(foodexp.exog_name[0])
+    >>> ax.set_ylabel(foodexp.endog_name)
+    >>> qqline(ax, 'r', x, y)
+    >>> plt.show()
+
+    .. plot:: plots/graphics_gofplots_qqplot_qqline.py
     """
     if line == '45':
         end_pts = lzip(ax.get_xlim(), ax.get_ylim())
@@ -615,7 +739,7 @@ def qqline(ax, line, x=None, y=None, dist=None, fmt='r-'):
         raise ValueError("If line is not 45, x and y cannot be None.")
     elif line == 'r':
         # could use ax.lines[0].get_xdata(), get_ydata(),
-        # but don't know axes are 'clean'
+        # but do not know axes are 'clean'
         y = OLS(y, add_constant(x)).fit().fittedvalues
         ax.plot(x,y,fmt)
     elif line == 's':
@@ -632,7 +756,7 @@ def qqline(ax, line, x=None, y=None, dist=None, fmt='r-'):
         ax.plot(x, m*x + b, fmt)
 
 
-#about 10x faster than plotting_position in sandbox and mstats
+# about 10x faster than plotting_position in sandbox and mstats
 def plotting_pos(nobs, a):
     """
     Generates sequence of plotting positions
@@ -647,7 +771,7 @@ def plotting_pos(nobs, a):
 
     Returns
     -------
-    plotting_positions : array
+    plotting_positions : ndarray
         The plotting positions
 
     Notes
@@ -655,11 +779,12 @@ def plotting_pos(nobs, a):
     The plotting positions are given by (i - a)/(nobs - 2*a + 1) for i in
     range(0,nobs+1)
 
-    See also
+    See Also
     --------
     scipy.stats.mstats.plotting_positions
     """
-    return (np.arange(1.,nobs+1) - a)/(nobs- 2*a + 1)
+    return (np.arange(1., nobs + 1) - a)/(nobs - 2 * a + 1)
+
 
 def _fmt_probplot_axis(ax, dist, nobs):
     """
@@ -668,7 +793,7 @@ def _fmt_probplot_axis(ax, dist, nobs):
 
     Parameteters
     ------------
-    ax : Matplotlib AxesSubplot instance, optional
+    ax : AxesSubplot, optional
         The axis to be formatted
     nobs : scalar
         Numbero of observations in the sample
@@ -682,15 +807,16 @@ def _fmt_probplot_axis(ax, dist, nobs):
     """
     _check_for_ppf(dist)
     if nobs < 50:
-        axis_probs = np.array([1,2,5,10,20,30,40,50,60,
-                               70,80,90,95,98,99,])/100.0
+        axis_probs = np.array([1, 2, 5, 10, 20, 30, 40, 50, 60,
+                               70, 80, 90, 95, 98, 99, ]) / 100.0
     elif nobs < 500:
-        axis_probs = np.array([0.1,0.2,0.5,1,2,5,10,20,30,40,50,60,70,
-                               80,90,95,98,99,99.5,99.8,99.9])/100.0
+        axis_probs = np.array([0.1, 0.2, 0.5, 1, 2, 5, 10, 20, 30, 40, 50, 60,
+                               70, 80, 90, 95, 98, 99, 99.5, 99.8,
+                               99.9]) / 100.0
     else:
-        axis_probs = np.array([0.01,0.02,0.05,0.1,0.2,0.5,1,2,5,10,
-                               20,30,40,50,60,70,80,90,95,98,99,99.5,
-                               99.8,99.9,99.95,99.98,99.99])/100.0
+        axis_probs = np.array([0.01, 0.02, 0.05, 0.1, 0.2, 0.5, 1, 2, 5, 10,
+                               20, 30, 40, 50, 60, 70, 80, 90, 95, 98, 99,
+                               99.5, 99.8, 99.9, 99.95, 99.98, 99.99]) / 100.0
     axis_qntls = dist.ppf(axis_probs)
     ax.set_xticks(axis_qntls)
     ax.set_xticklabels(axis_probs*100, rotation=45,
@@ -699,6 +825,7 @@ def _fmt_probplot_axis(ax, dist, nobs):
                        verticalalignment='center')
     ax.set_xlim([axis_qntls.min(), axis_qntls.max()])
 
+
 def _do_plot(x, y, dist=None, line=False, ax=None, fmt='bo', **kwargs):
     """
     Boiler plate plotting function for the `ppplot`, `qqplot`, and
@@ -706,13 +833,13 @@ def _do_plot(x, y, dist=None, line=False, ax=None, fmt='bo', **kwargs):
 
     Parameteters
     ------------
-    x, y : array-like
+    x, y : array_like
         Data to be plotted
     dist : scipy.stats.distribution
         A scipy.stats distribution, needed if `line` is 'q'.
     line : str {'45', 's', 'r', q'} or None
         Options for the reference line to which the data is compared.
-    ax : Matplotlib AxesSubplot instance, optional
+    ax : AxesSubplot, optional
         If given, this subplot is used to plot in instead of a new figure being
         created.
     fmt : str, optional
@@ -722,9 +849,10 @@ def _do_plot(x, y, dist=None, line=False, ax=None, fmt='bo', **kwargs):
 
     Returns
     -------
-    fig : Matplotlib Figure instance
-    ax : Matplotlib AxesSubplot instance (see Parameters)
-
+    fig : Figure
+        The figure containing `ax`.
+    ax : AxesSubplot
+        The original axes if provided.  Otherwise a new instance.
     """
     fig, ax = utils.create_mpl_ax(ax)
     ax.set_xmargin(0.02)
@@ -738,6 +866,7 @@ def _do_plot(x, y, dist=None, line=False, ax=None, fmt='bo', **kwargs):
 
     return fig, ax
 
+
 def _check_for_ppf(dist):
     if not hasattr(dist, 'ppf'):
         raise ValueError("distribution must have a ppf method")
