@@ -7,16 +7,15 @@ Racine, Jeff. (2008) "Nonparametric Econometrics: A Primer," Foundation and
     Trends in Econometrics: Vol 3: No 1, pp1-88.
     http://dx.doi.org/10.1561/0800000009
 
-http://en.wikipedia.org/wiki/Kernel_%28statistics%29
+https://en.wikipedia.org/wiki/Kernel_%28statistics%29
 
 Silverman, B.W.  Density Estimation for Statistics and Data Analysis.
 """
-from __future__ import absolute_import, print_function, division
-from statsmodels.compat.python import range
 import numpy as np
 from scipy import integrate, stats
 from statsmodels.sandbox.nonparametric import kernels
-from statsmodels.tools.decorators import (cache_readonly, resettable_cache)
+from statsmodels.tools.decorators import cache_readonly
+from statsmodels.tools.validation import array_like
 from . import bandwidths
 from .kdetools import (forrt, revrt, silverman_transform)
 from .linbin import fast_linbin
@@ -44,7 +43,7 @@ class KDEUnivariate(object):
 
     Parameters
     ----------
-    endog : array-like
+    endog : array_like
         The variable for which the density estimate is desired.
 
     Notes
@@ -73,11 +72,10 @@ class KDEUnivariate(object):
     >>> dens.fit()
     >>> plt.plot(dens.cdf)
     >>> plt.show()
-
     """
 
     def __init__(self, endog):
-        self.endog = np.asarray(endog)
+        self.endog = array_like(endog, "endog", ndim=1, contiguous=True)
 
     def fit(self, kernel="gau", bw="normal_reference", fft=True, weights=None,
             gridsize=None, adjust=1, cut=3, clip=(-np.inf, np.inf)):
@@ -153,7 +151,7 @@ class KDEUnivariate(object):
         self.kernel.weights = weights
         if weights is not None:
             self.kernel.weights /= weights.sum()
-        self._cache = resettable_cache()
+        self._cache = {}
 
     @cache_readonly
     def cdf(self):
@@ -188,7 +186,6 @@ class KDEUnivariate(object):
         Notes
         -----
         Will not work if fit has not been called.
-
         """
         _checkisfit(self)
         return -np.log(self.sf)
@@ -267,7 +264,7 @@ def kdensity(X, kernel="gau", bw="normal_reference", weights=None, gridsize=None
 
     Parameters
     ----------
-    X : array-like
+    X : array_like
         The variable for which the density estimate is desired.
     kernel : str
         The Kernel to be used. Choices are
@@ -301,9 +298,9 @@ def kdensity(X, kernel="gau", bw="normal_reference", weights=None, gridsize=None
 
     Returns
     -------
-    density : array
+    density : ndarray
         The densities estimated at the grid points.
-    grid : array, optional
+    grid : ndarray, optional
         The grid points at which the density is estimated.
 
     Notes
@@ -319,8 +316,8 @@ def kdensity(X, kernel="gau", bw="normal_reference", weights=None, gridsize=None
 
     nobs = len(X) # after trim
 
-    if gridsize == None:
-        gridsize = max(nobs,50) # don't need to resize if no FFT
+    if gridsize is None:
+        gridsize = max(nobs,50) # do not need to resize if no FFT
 
         # handle weights
     if weights is None:
@@ -329,7 +326,7 @@ def kdensity(X, kernel="gau", bw="normal_reference", weights=None, gridsize=None
     else:
         # ensure weights is a numpy array
         weights = np.asarray(weights)
-        
+
         if len(weights) != len(clip_x):
             msg = "The length of the weights must be the same as the given X."
             raise ValueError(msg)
@@ -356,7 +353,7 @@ def kdensity(X, kernel="gau", bw="normal_reference", weights=None, gridsize=None
     kern.seth(bw)
 
     # truncate to domain
-    if kern.domain is not None: # won't work for piecewise kernels like parzen
+    if kern.domain is not None: # will not work for piecewise kernels like parzen
         z_lo, z_high = kern.domain
         domain_mask = (k < z_lo) | (k > z_high)
         k = kern(k) # estimate density
@@ -380,7 +377,7 @@ def kdensityfft(X, kernel="gau", bw="normal_reference", weights=None, gridsize=N
 
     Parameters
     ----------
-    X : array-like
+    X : array_like
         The variable for which the density estimate is desired.
     kernel : str
         ONLY GAUSSIAN IS CURRENTLY IMPLEMENTED.
@@ -417,14 +414,14 @@ def kdensityfft(X, kernel="gau", bw="normal_reference", weights=None, gridsize=N
 
     Returns
     -------
-    density : array
+    density : ndarray
         The densities estimated at the grid points.
-    grid : array, optional
+    grid : ndarray, optional
         The grid points at which the density is estimated.
 
     Notes
     -----
-    Only the default kernel is implemented. Weights aren't implemented yet.
+    Only the default kernel is implemented. Weights are not implemented yet.
     This follows Silverman (1982) with changes suggested by Jones and Lotwick
     (1984). However, the discretization step is replaced by linear binning
     of Fan and Marron (1994). This should be extended to accept the parts
@@ -432,8 +429,7 @@ def kdensityfft(X, kernel="gau", bw="normal_reference", weights=None, gridsize=N
     cross-validation.
 
     References
-    ---------- ::
-
+    ----------
     Fan, J. and J.S. Marron. (1994) `Fast implementations of nonparametric
         curve estimators`. Journal of Computational and Graphical Statistics.
         3.1, 35-56.
@@ -445,7 +441,7 @@ def kdensityfft(X, kernel="gau", bw="normal_reference", weights=None, gridsize=N
         Series C. 31.2, 93-9.
     """
     X = np.asarray(X)
-    X = X[np.logical_and(X > clip[0], X < clip[1])] # won't work for two columns.
+    X = X[np.logical_and(X > clip[0], X < clip[1])] # will not work for two columns.
                                                 # will affect underlying data?
 
     # Get kernel object corresponding to selection
@@ -460,7 +456,7 @@ def kdensityfft(X, kernel="gau", bw="normal_reference", weights=None, gridsize=N
     nobs = len(X) # after trim
 
     # 1 Make grid and discretize the data
-    if gridsize == None:
+    if gridsize is None:
         gridsize = np.max((nobs, 512.))
     gridsize = 2**np.ceil(np.log2(gridsize)) # round to next power of 2
 
@@ -491,12 +487,12 @@ def kdensityfft(X, kernel="gau", bw="normal_reference", weights=None, gridsize=N
     y = forrt(binned)
 
     # step 3 and 4 for optimal bw compute zstar and the density estimate f
-    # don't have to redo the above if just changing bw, ie., for cross val
+    # do not have to redo the above if just changing bw, ie., for cross val
 
 #NOTE: silverman_transform is the closed form solution of the FFT of the
 #gaussian kernel. Not yet sure how to generalize it.
     zstar = silverman_transform(bw, gridsize, RANGE)*y # 3.49 in Silverman
-                                                   # 3.50 w Gaussian kernel
+                                                    # 3.50 w Gaussian kernel
     f = revrt(zstar)
     if retgrid:
         return f, grid, bw
@@ -547,4 +543,4 @@ if __name__ == "__main__":
     except:
 #        ft = np.loadtxt('./ft_silver.csv')
 #        smooth = np.loadtxt('./smooth_silver.csv')
-        print("Didn't get the estimates from the Silverman algorithm")
+        print("Did not get the estimates from the Silverman algorithm")
