@@ -30,7 +30,6 @@ refactoring
 
 
 """
-from __future__ import print_function
 from statsmodels.compat.python import iteritems
 import numpy as np
 from scipy import stats, optimize
@@ -44,7 +43,7 @@ def ttest_power(effect_size, nobs, alpha, df=None, alternative='two-sided'):
         df = nobs - 1
 
     if alternative in ['two-sided', '2s']:
-        alpha_ = alpha / 2.  #no inplace changes, doesn't work
+        alpha_ = alpha / 2.  #no inplace changes, does not work
     elif alternative in ['smaller', 'larger']:
         alpha_ = alpha
     else:
@@ -77,7 +76,7 @@ def normal_power(effect_size, nobs, alpha, alternative='two-sided', sigma=1.):
     d = effect_size
 
     if alternative in ['two-sided', '2s']:
-        alpha_ = alpha / 2.  #no inplace changes, doesn't work
+        alpha_ = alpha / 2.  #no inplace changes, does not work
     elif alternative in ['smaller', 'larger']:
         alpha_ = alpha
     else:
@@ -307,38 +306,41 @@ class Power(object):
 
     def plot_power(self, dep_var='nobs', nobs=None, effect_size=None,
                    alpha=0.05, ax=None, title=None, plt_kwds=None, **kwds):
-        '''plot power with number of observations or effect size on x-axis
+        """
+        Plot power with number of observations or effect size on x-axis
 
         Parameters
         ----------
-        dep_var : string in ['nobs', 'effect_size', 'alpha']
+        dep_var : {'nobs', 'effect_size', 'alpha'}
             This specifies which variable is used for the horizontal axis.
             If dep_var='nobs' (default), then one curve is created for each
             value of ``effect_size``. If dep_var='effect_size' or alpha, then
             one curve is created for each value of ``nobs``.
-        nobs : scalar or array_like
+        nobs : {scalar, array_like}
             specifies the values of the number of observations in the plot
-        effect_size : scalar or array_like
+        effect_size : {scalar, array_like}
             specifies the values of the effect_size in the plot
-        alpha : float or array_like
+        alpha : {float, array_like}
             The significance level (type I error) used in the power
             calculation. Can only be more than a scalar, if ``dep_var='alpha'``
         ax : None or axis instance
             If ax is None, than a matplotlib figure is created. If ax is a
             matplotlib axis instance, then it is reused, and the plot elements
             are created with it.
-        title : string
+        title : str
             title for the axis. Use an empty string, ``''``, to avoid a title.
-        plt_kwds : None or dict
+        plt_kwds : {None, dict}
             not used yet
-        kwds : optional keywords for power function
+        kwds : dict
             These remaining keyword arguments are used as arguments to the
             power function. Many power function support ``alternative`` as a
             keyword argument, two-sample test support ``ratio``.
 
         Returns
         -------
-        fig : matplotlib figure instance
+        Figure
+            If `ax` is None, the created figure.  Otherwise the figure to which
+            `ax` is connected.
 
         Notes
         -----
@@ -349,7 +351,7 @@ class Power(object):
         TODO: fix this for FTestPower and GofChisquarePower
 
         TODO: maybe add line variable, if we want more than nobs and effectsize
-        '''
+        """
         #if pwr_kwds is None:
         #    pwr_kwds = {}
         from statsmodels.graphics import utils
@@ -416,7 +418,7 @@ class TTestPower(Power):
         df : int or float
             degrees of freedom. By default this is None, and the df from the
             one sample or paired ttest is used, ``df = nobs1 - 1``
-        alternative : string, 'two-sided' (default), 'larger', 'smaller'
+        alternative : str, 'two-sided' (default), 'larger', 'smaller'
             extra argument to choose whether the power is calculated for a
             two-sided (default) or one sided test. The one-sided test can be
             either 'larger', 'smaller'.
@@ -463,7 +465,7 @@ class TTestPower(Power):
             power of the test, e.g. 0.8, is one minus the probability of a
             type II error. Power is the probability that the test correctly
             rejects the Null Hypothesis if the Alternative Hypothesis is true.
-        alternative : string, 'two-sided' (default) or 'one-sided'
+        alternative : str, 'two-sided' (default) or 'one-sided'
             extra argument to choose whether the power is calculated for a
             two-sided (default) or one sided test.
             'one-sided' assumes we are in the relevant tail.
@@ -533,7 +535,7 @@ class TTestIndPower(Power):
         df : int or float
             degrees of freedom. By default this is None, and the df from the
             ttest with pooled variance is used, ``df = (nobs1 - 1 + nobs2 - 1)``
-        alternative : string, 'two-sided' (default), 'larger', 'smaller'
+        alternative : str, 'two-sided' (default), 'larger', 'smaller'
             extra argument to choose whether the power is calculated for a
             two-sided (default) or one sided test. The one-sided test can be
             either 'larger', 'smaller'.
@@ -587,7 +589,7 @@ class TTestIndPower(Power):
             sample 1. see description of nobs1
             The default for ratio is 1; to solve for ratio given the other
             arguments it has to be explicitly set to None.
-        alternative : string, 'two-sided' (default), 'larger', 'smaller'
+        alternative : str, 'two-sided' (default), 'larger', 'smaller'
             extra argument to choose whether the power is calculated for a
             two-sided (default) or one sided test. The one-sided test can be
             either 'larger', 'smaller'.
@@ -648,7 +650,7 @@ class NormalIndPower(Power):
         ratio : float
             ratio of the number of observations in sample 2 relative to
             sample 1. see description of nobs1
-        alternative : string, 'two-sided' (default), 'larger', 'smaller'
+        alternative : str, 'two-sided' (default), 'larger', 'smaller'
             extra argument to choose whether the power is calculated for a
             two-sided (default) or one sided test. The one-sided test can be
             either 'larger', 'smaller'.
@@ -708,7 +710,7 @@ class NormalIndPower(Power):
             sample 1. see description of nobs1
             The default for ratio is 1; to solve for ration given the other
             arguments it has to be explicitly set to None.
-        alternative : string, 'two-sided' (default), 'larger', 'smaller'
+        alternative : str, 'two-sided' (default), 'larger', 'smaller'
             extra argument to choose whether the power is calculated for a
             two-sided (default) or one sided test. The one-sided test can be
             either 'larger', 'smaller'.
@@ -810,7 +812,7 @@ class FTestPower(Power):
             power of the test, e.g. 0.8, is one minus the probability of a
             type II error. Power is the probability that the test correctly
             rejects the Null Hypothesis if the Alternative Hypothesis is true.
-        alternative : string, 'two-sided' (default) or 'one-sided'
+        alternative : str, 'two-sided' (default) or 'one-sided'
             extra argument to choose whether the power is calculated for a
             two-sided (default) or one sided test.
             'one-sided' assumes we are in the relevant tail.
@@ -819,7 +821,7 @@ class FTestPower(Power):
         -------
         value : float
             The value of the parameter that was set to None in the call. The
-            value solves the power equation given the remainding parameters.
+            value solves the power equation given the remaining parameters.
 
 
         Notes
@@ -900,7 +902,7 @@ class FTestAnovaPower(Power):
         -------
         value : float
             The value of the parameter that was set to None in the call. The
-            value solves the power equation given the remainding parameters.
+            value solves the power equation given the remaining parameters.
 
 
         Notes
@@ -1068,7 +1070,7 @@ class _GofChisquareIndPower(Power):
             sample 1. see description of nobs1
             The default for ratio is 1; to solve for ration given the other
             arguments it has to be explicitely set to None.
-        alternative : string, 'two-sided' (default) or 'one-sided'
+        alternative : str, 'two-sided' (default) or 'one-sided'
             extra argument to choose whether the power is calculated for a
             two-sided (default) or one sided test.
             'one-sided' assumes we are in the relevant tail.
@@ -1119,7 +1121,7 @@ class _GofChisquareIndPower(Power):
             sample 1. see description of nobs1
             The default for ratio is 1; to solve for ration given the other
             arguments it has to be explicitely set to None.
-        alternative : string, 'two-sided' (default) or 'one-sided'
+        alternative : str, 'two-sided' (default) or 'one-sided'
             extra argument to choose whether the power is calculated for a
             two-sided (default) or one sided test.
             'one-sided' assumes we are in the relevant tail.
@@ -1128,7 +1130,7 @@ class _GofChisquareIndPower(Power):
         -------
         value : float
             The value of the parameter that was set to None in the call. The
-            value solves the power equation given the remainding parameters.
+            value solves the power equation given the remaining parameters.
 
 
         Notes
